import javax.swing.*;
import java.awt.*;

public class FifteenPanel extends JPanel {

    private static final int SIZE = 400;
    public static final int SIDE = SIZE/4; // needed by FifteenListener
    private static final int CORNERDIAM = SIDE/6;
    private static final int XOFFSET = CORNERDIAM;
    private static final int YOFFSET = 4*CORNERDIAM;
    private static final Color GOLD = new Color(245, 170, 10); 
    private static final Font font = new Font(Font.SANS_SERIF,Font.BOLD,SIDE/2);

    private FifteenModel model;

    public FifteenPanel(FifteenModel model) {
        this.model = model;
        setPreferredSize(new Dimension(SIZE,SIZE));
        setBackground(Color.BLACK);
        setOpaque(true);
        addMouseListener(new FifteenListener(model, this));
    }

    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        g.setFont(font);
        for (int r=0; r<4; r++)
            for(int c=0; c<4; c++)
                drawPiece(g,r,c);
    }

    private void drawPiece(Graphics g, int r, int c) {
        int n = model.getState(r,c);
        if (n>0) {
            g.setColor(getColor(n));
            g.fillRoundRect(SIDE*c,SIDE*r,SIDE,SIDE,CORNERDIAM,CORNERDIAM);
            g.setColor(Color.BLACK);
            g.drawRoundRect(SIDE*c,SIDE*r,SIDE,SIDE,CORNERDIAM,CORNERDIAM);
            String s = (n<10 ? " " : "") + n;
            g.setColor(GOLD);
            g.drawString(s,SIDE*c+XOFFSET, SIDE*r+YOFFSET);
        }
    }

    private Color getColor(int i) {
        return i%2==0 ?  Color.RED : Color.WHITE;
    }


}
